@@ -1,6 +1,6 @@
 /*
  *   This file is part of Auralquiz
- *   Copyright 2011-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2011-2017  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -1107,7 +1107,7 @@ void AuralWindow::showAbout()
                        QString("<big><b>Auralquiz v%1</b></big>")
                        .arg(qApp->applicationVersion())
                        + "<br />"
-                       "Copyright 2011-2016  JanKusanagi"
+                       "Copyright 2011-2017  JanKusanagi"
                        "<br />"
                        "<br />"
                        "<a href=\"https://jancoding.wordpress.com/auralquiz\">"
@@ -1227,13 +1227,15 @@ void AuralWindow::newQuestion()
         //qDebug() << "answerCount" << answerCount;
 
         // If text in current button is NOT the correct answer (lowercase comparison!)
-        if (buttonTexts[answerCount].toLower() != musicFiles[questionType].at(currentMusicFile).toLower())
+        if (buttonTexts[answerCount].toLower() != musicFiles[questionType]
+                                                  .at(currentMusicFile).toLower())
         {
             bool isGood = true;
             for (int previousAnswer = 0; previousAnswer != answerCount; ++previousAnswer)
             {
                 // Compare strings in LOWERCASE (Metallica ~= metallica)
-                if (buttonTexts[answerCount].toLower() != buttonTexts[previousAnswer].toLower())
+                if (buttonTexts[answerCount].toLower()
+                 != buttonTexts[previousAnswer].toLower())
                 {
                     isGood = true;
                     //qDebug() << "is GOOD" << previousAnswer;
@@ -1286,7 +1288,7 @@ void AuralWindow::newQuestion()
             QString fixedAnswer = answerButton[counter]->text();
             fixedAnswer.replace(QRegExp("&"), "&&"); // fix non-accelerator
             fixedAnswer.truncate(64); // avoid wiiiiide buttons
-            // FIXME 0.9.x: truncate position should be calculated, not hardcoded
+            // FIXME 1.1.x: truncate position should be calculated, not hardcoded
             // For now, 64 seems sane
 
             answerButton[counter]->setText(fixedAnswer);
