@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ca_ES">
+<TS version="2.1" language="ca_ES">
 <context>
     <name>AnswerBox</name>
     <message>
@@ -77,7 +77,7 @@
         <translation>Potser no tens cap motor de Phonon instal·lat.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="789"/>
+        <location filename="../src/auralwindow.cpp" line="790"/>
         <source>%1 songs available</source>
         <translation>%1 cançons disponibles</translation>
     </message>
@@ -139,10 +139,6 @@ Potser el teu Phonon-backend no té suport pel format d&apos;arxiu MP3.</transla
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz carrega tota la teva música d&apos;una carpeta especificada, i fa preguntes sobre ella, reproduint una petita peça de cada arxiu de música com a pista.</translation>
     </message>
-    <message>
-        <source>Main screen image based on Oxygen icons: http://www.oxygen-icons.org/ (LGPL licensed)</source>
-        <translation type="obsolete">Imatge de la pantalla principal basada en Oxygen Icons: http://www.oxygen-icons.org/ (llicencia LGPL)</translation>
-    </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="777"/>
         <source>Starting!</source>
@@ -375,7 +371,7 @@ Necessites música de 5 artistes diferents, com a mínim, pero poder generar pre
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="359"/>
+        <location filename="../src/musicanalyzer.cpp" line="361"/>
         <source>Please reload music info</source>
         <translation>Si us plau, recarrega la info de música</translation>
     </message>
@@ -394,51 +390,41 @@ Necessites música de 5 artistes diferents, com a mínim, pero poder generar pre
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
         <translation>Si us plau, sel·lecciona un altre directori que contingui arxius Ogg, FLAC o MP3, i prova de nou.</translation>
     </message>
-    <message>
-        <source>Music analysis was canceled</source>
-        <translation type="obsolete">S&apos;ha cancel·lat l&apos;anàlisi de la música</translation>
-    </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="276"/>
         <source>There is no music!</source>
         <translation>No hi ha música!</translation>
     </message>
-    <message>
-        <source>There are no valid music files in your selected music directory.
-Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="obsolete">No hi han arxius de música vàlids al teu directori de música sel·leccionat.
-Si us plau, sel·lecciona un altre directori que contingui arxius Ogg, FLAC o MP3, i prova de nou.</translation>
-    </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="383"/>
+        <location filename="../src/musicanalyzer.cpp" line="385"/>
         <source>Please choose another music folder</source>
         <translation>Si us plau, sel·lecciona una altra carpeta de música</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
         <translation>Analitzant %1 arxius a %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="295"/>
+        <location filename="../src/musicanalyzer.cpp" line="297"/>
         <source>Cancel analysis</source>
         <translation>Cancel·lar l&apos;anàlisi</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="298"/>
+        <location filename="../src/musicanalyzer.cpp" line="300"/>
         <source>Analyzing your music...</source>
         <translation>Analitzant la teva música...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="384"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation>La carpeta que has seleccionat no té prou arxius de música vàlids</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="394"/>
+        <location filename="../src/musicanalyzer.cpp" line="396"/>
         <source>&amp;Start game</source>
         <translation>Començar &amp;joc</translation>
     </message>
@@ -521,17 +507,7 @@ under %2</source>
         <translation>En aquest nivell hauràs de fer clic al botó correcte, o apretar les tecles 1, 2, 3 i 4 del teclat.</translation>
     </message>
     <message>
-        <source>Is this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">En aquest nivell hauràs de fer clic al botó correcte, o apretar les tecles 1, 2, 3 i 4 del teclat.</translation>
-    </message>
-    <message>
-        <source>Is this level you&apos;ll have to click the correct button,
-or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">En aquest nivell hauràs de fer clic al botó correcte,
-o apretar les tecles 1, 2, 3 i 4 del teclat.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="459"/>
+        <location filename="../src/optionsdialog.cpp" line="460"/>
         <source>&amp;Save options</source>
         <translation>&amp;Guardar opcions</translation>
     </message>
@@ -576,13 +552,7 @@ o apretar les tecles 1, 2, 3 i 4 del teclat.</translation>
         <translation>Molt difícil! Tecleja la resposta</translation>
     </message>
     <message>
-        <source>In this level you&apos;ll have to type the answer.
-It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="obsolete">En aquest nivell hauràs d&apos;escriure la resposta.
-No es gaire estricte, o sigui que no t&apos;has de preocupar de les majúscules, comes, etc.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="489"/>
+        <location filename="../src/optionsdialog.cpp" line="490"/>
         <source>Start!</source>
         <translation>Començar!</translation>
     </message>
@@ -636,7 +606,7 @@ No es gaire estricte, o sigui que no t&apos;has de preocupar de les majúscules,
         <translation>T.E.</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="119"/>
+        <location filename="../src/ranking.cpp" line="124"/>
         <source>What?? Zero points!!
 You&apos;re all sooo bad!</source>
         <comment>Plural, all players</comment>
@@ -644,7 +614,7 @@ You&apos;re all sooo bad!</source>
 Sou tots mooolt dolents!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="125"/>
+        <location filename="../src/ranking.cpp" line="130"/>
         <source>Zero points!
 %1, you&apos;re very bad!!</source>
         <comment>%1 is the name of a player</comment>
@@ -652,44 +622,44 @@ Sou tots mooolt dolents!</translation>
 %1, se&apos;t dóna molt malament!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="141"/>
+        <location filename="../src/ranking.cpp" line="146"/>
         <source>Draw between %1 and %2!</source>
         <comment>%1 and %2 are player names</comment>
         <translation>Empat entre %1 i %2!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="151"/>
+        <location filename="../src/ranking.cpp" line="156"/>
         <source>You&apos;re very good!!</source>
         <translation>Se&apos;t dóna molt be!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="158"/>
+        <location filename="../src/ranking.cpp" line="163"/>
         <source>Congratulations, %1!!</source>
         <comment>%1 is the name of the winner</comment>
         <translation>Felicitats, %1!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="168"/>
+        <location filename="../src/ranking.cpp" line="173"/>
         <source>That was amazing!!</source>
         <translation>Ha sigut increïble!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="172"/>
+        <location filename="../src/ranking.cpp" line="177"/>
         <source>That was quite good!</source>
         <translation>Ha estat força bé!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="176"/>
+        <location filename="../src/ranking.cpp" line="181"/>
         <source>You can do better...</source>
         <translation>Pots fer-ho millor...</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="155"/>
+        <location filename="../src/ranking.cpp" line="160"/>
         <source>You&apos;re good!</source>
         <translation>Ets bo!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="192"/>
+        <location filename="../src/ranking.cpp" line="197"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
