@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="cs_CZ">
+<TS version="2.1" language="cs_CZ">
 <context>
     <name>AnswerBox</name>
     <message>
@@ -106,7 +106,7 @@
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. Feel free to add your contact information, such as e-mail. If there was another translator before you, add your name after theirs ;)</comment>
         <translatorcomment>(note by Jan: This should read &apos;Czech translation by YourName&apos; ;)</translatorcomment>
-        <translation type="unfinished">Anglický překlad: Jan Kusanagi.</translation>
+        <translation>Překlad do češtiny: Pavel Fric.</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1133"/>
@@ -116,7 +116,7 @@
     <message>
         <location filename="../src/auralwindow.cpp" line="1135"/>
         <source>Main screen image and some icons are based on Oxygen icons, under LGPL license.</source>
-        <translation type="unfinished"></translation>
+        <translation>Obrázek na hlavní obrazovce a některé ikony založen na ikonách Oxygen vydaných pod licencí LGPL.</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1373"/>
@@ -185,10 +185,6 @@ Možná vaše jádro Phonon nemá podporu pro formát MP3.</translation>
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz nahrává všechnu vaši hudbu ze zadané složky a ptá se na ni přehrávaje kousek z každého hudebního souboru jako nápovědu.</translation>
     </message>
-    <message>
-        <source>Main screen image based on Oxygen icons: http://www.oxygen-icons.org/ (LGPL licensed)</source>
-        <translation type="obsolete">Obrázek na hlavní obrazovce je založen na ikonách Oxygen: http://www.oxygen-icons.org/ (LGPL licensed)</translation>
-    </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="43"/>
         <source>This seems to be the first time you use Auralquiz.
@@ -213,7 +209,7 @@ Prohlídka může chvíli trvat a program nebude odpovídat, dokud nebude hotov
     <message>
         <location filename="../src/auralwindow.cpp" line="668"/>
         <source>Maybe you don&apos;t have any Phonon backends installed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Může být, že nemáte nainstalovánu podpůrnou vrstvu Phonon.</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="777"/>
@@ -236,9 +232,9 @@ Prohlídka může chvíli trvat a program nebude odpovídat, dokud nebude hotov
         <translation>Hodně štěstí!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="789"/>
+        <location filename="../src/auralwindow.cpp" line="790"/>
         <source>%1 songs available</source>
-        <translation type="unfinished"></translation>
+        <translation>Dostupných %1 písní</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1031"/>
@@ -306,7 +302,7 @@ Na tvoření otázek potřebujete hudbu od alespoň pěti různých umělců.</t
         <location filename="../src/auralwindow.cpp" line="1470"/>
         <source>%1 by %2</source>
         <comment>1=song title, 2=author name</comment>
-        <translation type="unfinished"></translation>
+        <translation>%1 od %2</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1475"/>
@@ -376,48 +372,38 @@ Na tvoření otázek potřebujete hudbu od alespoň pěti různých umělců.</t
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="359"/>
+        <location filename="../src/musicanalyzer.cpp" line="361"/>
         <source>Please reload music info</source>
         <translation>Nahrajte, prosím, informace o hudbě</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="256"/>
         <source>Music analysis was cancelled</source>
-        <translation type="unfinished">Rozbor hudby byl zrušen</translation>
+        <translation>Rozbor hudby byl zrušen</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="269"/>
         <source>There are no valid music files in your selected music directory.</source>
-        <translation type="unfinished">Ve vámi vybraném adresáři s hudbou nejsou žádné platné hudební soubory.</translation>
+        <translation>Ve vámi vybraném adresáři s hudbou nejsou žádné platné hudební soubory.</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="272"/>
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="unfinished">Vyberte, prosím, jiný adresář obsahující soubory Ogg, FLAC nebo MP3 a zkuste to znovu.</translation>
-    </message>
-    <message>
-        <source>Music analysis was canceled</source>
-        <translation type="obsolete">Rozbor hudby byl zrušen</translation>
+        <translation>Vyberte, prosím, jiný adresář obsahující soubory Ogg, FLAC nebo MP3 a zkuste to znovu.</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="276"/>
         <source>There is no music!</source>
         <translation>Není tu žádná hudba!</translation>
     </message>
-    <message>
-        <source>There are no valid music files in your selected music directory.
-Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="obsolete">Ve vámi vybraném adresáři s hudbou nejsou žádné platné hudební soubory.
-Vyberte, prosím, jiný adresář obsahující soubory Ogg, FLAC nebo MP3 a zkuste to znovu.</translation>
-    </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="383"/>
+        <location filename="../src/musicanalyzer.cpp" line="385"/>
         <source>Please choose another music folder</source>
         <translation>Vyberte, prosím, jiný adresář s hudbou</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
@@ -425,22 +411,22 @@ under %2</source>
 v %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="295"/>
+        <location filename="../src/musicanalyzer.cpp" line="297"/>
         <source>Cancel analysis</source>
         <translation>Zrušit rozbor</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="298"/>
+        <location filename="../src/musicanalyzer.cpp" line="300"/>
         <source>Analyzing your music...</source>
         <translation>Provádí se rozbor vaší hudby...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="384"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation>Vámi vybraná složka neobsahuje dost platných hudebních souborů</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="394"/>
+        <location filename="../src/musicanalyzer.cpp" line="396"/>
         <source>&amp;Start game</source>
         <translation>&amp;Spustit hru</translation>
     </message>
@@ -550,41 +536,25 @@ v %2</translation>
     <message>
         <location filename="../src/optionsdialog.cpp" line="363"/>
         <source>In this level you&apos;ll have to type the answer.</source>
-        <translation type="unfinished">Na této úrovni musíte napsat odpověď.</translation>
+        <translation>Na této úrovni musíte napsat odpověď.</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="366"/>
         <source>It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="unfinished">Není to příliš přísné, takže se nemusíte obávat velikosti písmen, čárek a tak podobně.</translation>
+        <translation>Není to příliš přísné, takže se nemusíte obávat velikosti písmen, čárek a tak podobně.</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="373"/>
         <source>In this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="unfinished">Na této úrovni musíte klepnout na správné tlačítko, nebo na vaší klávesnici stisknout klávesu 1, 2, 3 nebo 4.</translation>
+        <translation>Na této úrovni musíte klepnout na správné tlačítko, nebo na vaší klávesnici stisknout klávesu 1, 2, 3 nebo 4.</translation>
     </message>
     <message>
-        <source>Is this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">Na této úrovni musíte klepnout na správné tlačítko, nebo na vaší klávesnici stisknout klávesu 1, 2, 3 nebo 4.</translation>
-    </message>
-    <message>
-        <source>In this level you&apos;ll have to type the answer.
-It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="obsolete">Na této úrovni musíte napsat odpověď.
-Není to příliš přísné, takže se nemusíte obávat velikosti písmen, čárek a tak podobně.</translation>
-    </message>
-    <message>
-        <source>Is this level you&apos;ll have to click the correct button,
-or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">Na této úrovni musíte klepnout na správné tlačítko,
-nebo na vaší klávesnici stisknout klávesu 1, 2, 3 nebo 4.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="459"/>
+        <location filename="../src/optionsdialog.cpp" line="460"/>
         <source>&amp;Save options</source>
         <translation>&amp;Uložit volby</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="489"/>
+        <location filename="../src/optionsdialog.cpp" line="490"/>
         <source>Start!</source>
         <translation>Začít!</translation>
     </message>
@@ -638,7 +608,7 @@ nebo na vaší klávesnici stisknout klávesu 1, 2, 3 nebo 4.</translation>
         <translation>Překr. času</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="119"/>
+        <location filename="../src/ranking.cpp" line="124"/>
         <source>What?? Zero points!!
 You&apos;re all sooo bad!</source>
         <comment>Plural, all players</comment>
@@ -646,7 +616,7 @@ You&apos;re all sooo bad!</source>
 Jste na to všichni hodně moc bledě!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="125"/>
+        <location filename="../src/ranking.cpp" line="130"/>
         <source>Zero points!
 %1, you&apos;re very bad!!</source>
         <comment>%1 is the name of a player</comment>
@@ -654,44 +624,44 @@ Jste na to všichni hodně moc bledě!</translation>
 %1, jste na tom velmi špatně!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="141"/>
+        <location filename="../src/ranking.cpp" line="146"/>
         <source>Draw between %1 and %2!</source>
         <comment>%1 and %2 are player names</comment>
         <translation>Remíza mezi %1 a %2!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="151"/>
+        <location filename="../src/ranking.cpp" line="156"/>
         <source>You&apos;re very good!!</source>
         <translation>Jste velmi dobrý!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="158"/>
+        <location filename="../src/ranking.cpp" line="163"/>
         <source>Congratulations, %1!!</source>
         <comment>%1 is the name of the winner</comment>
         <translation>Blahopřání %1!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="168"/>
+        <location filename="../src/ranking.cpp" line="173"/>
         <source>That was amazing!!</source>
-        <translation type="unfinished"></translation>
+        <translation>To bylo úžasné!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="172"/>
+        <location filename="../src/ranking.cpp" line="177"/>
         <source>That was quite good!</source>
         <translation>To bylo docela dobré!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="176"/>
+        <location filename="../src/ranking.cpp" line="181"/>
         <source>You can do better...</source>
         <translation>Dokážete to udělat líp...</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="155"/>
+        <location filename="../src/ranking.cpp" line="160"/>
         <source>You&apos;re good!</source>
         <translation>Jste dobrý!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="192"/>
+        <location filename="../src/ranking.cpp" line="197"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
