@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="es_ES">
+<TS version="2.1" language="es_ES">
 <context>
     <name>AnswerBox</name>
     <message>
@@ -77,7 +77,7 @@
         <translation>Quizá no tienes ningún motor de Phonon instalado.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="789"/>
+        <location filename="../src/auralwindow.cpp" line="790"/>
         <source>%1 songs available</source>
         <translation>%1 canciones disponibles</translation>
     </message>
@@ -139,10 +139,6 @@ Tal vez tu Phonon-backend no tenga soporte para el formato de archivo MP3.</tran
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz carga toda tu música de una carpeta especificada, y pregunta sobre ella, reproduciendo una pequeña pieza de cada archivo de música como pista.</translation>
     </message>
-    <message>
-        <source>Main screen image based on Oxygen icons: http://www.oxygen-icons.org/ (LGPL licensed)</source>
-        <translation type="obsolete">Imagen de la pantalla principal basada en Oxygen Icons: http://www.oxygen-icons.org/ (licencia LGPL)</translation>
-    </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="777"/>
         <source>Starting!</source>
@@ -375,7 +371,7 @@ Necesitas música de al menos 5 artistas diferentes para poder generar preguntas
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="359"/>
+        <location filename="../src/musicanalyzer.cpp" line="361"/>
         <source>Please reload music info</source>
         <translation>Por favor, recarga la info de música</translation>
     </message>
@@ -394,51 +390,41 @@ Necesitas música de al menos 5 artistas diferentes para poder generar preguntas
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
         <translation>Por favor, selecciona otro directorio que contenga archivos Ogg, FLAC o MP3, e inténtalo de nuevo.</translation>
     </message>
-    <message>
-        <source>Music analysis was canceled</source>
-        <translation type="obsolete">Se ha cancelado el análisis de la música</translation>
-    </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="276"/>
         <source>There is no music!</source>
         <translation>¡No hay música!</translation>
     </message>
-    <message>
-        <source>There are no valid music files in your selected music directory.
-Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="obsolete">No hay archivos de música válidos en tu directorio de música seleccionado.
-Por favor, selecciona otro directorio que contenga archivos Ogg, FLAC o MP3, e intentalo de nuevo.</translation>
-    </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="383"/>
+        <location filename="../src/musicanalyzer.cpp" line="385"/>
         <source>Please choose another music folder</source>
         <translation>Por favor, selecciona otra carpeta de música</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
         <translation>Analizando %1 archivos en %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="295"/>
+        <location filename="../src/musicanalyzer.cpp" line="297"/>
         <source>Cancel analysis</source>
         <translation>Cancelar análisis</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="298"/>
+        <location filename="../src/musicanalyzer.cpp" line="300"/>
         <source>Analyzing your music...</source>
         <translation>Analizando tu música...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="384"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation>La carpeta que has seleccionado no tiene suficientes archivos de música válidos</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="394"/>
+        <location filename="../src/musicanalyzer.cpp" line="396"/>
         <source>&amp;Start game</source>
         <translation>Comenzar &amp;juego</translation>
     </message>
@@ -521,17 +507,7 @@ under %2</source>
         <translation>En este nivel tendrás que hacer click en el botón correcto, o apretar las teclas 1, 2, 3 y 4 del teclado.</translation>
     </message>
     <message>
-        <source>Is this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">En este nivel tendrás que hacer click en el botón correcto, o apretar las teclas 1, 2, 3 y 4 del teclado.</translation>
-    </message>
-    <message>
-        <source>Is this level you&apos;ll have to click the correct button,
-or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">En este nivel tendrás que hacer click en el botón correcto,
-o apretar las teclas 1, 2, 3 y 4 del teclado.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="459"/>
+        <location filename="../src/optionsdialog.cpp" line="460"/>
         <source>&amp;Save options</source>
         <translation>&amp;Guardar opciones</translation>
     </message>
@@ -576,13 +552,7 @@ o apretar las teclas 1, 2, 3 y 4 del teclado.</translation>
         <translation>¡Muy difícil! Teclea la respuesta</translation>
     </message>
     <message>
-        <source>In this level you&apos;ll have to type the answer.
-It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="obsolete">En este nivel tendrás que teclear la respuesta.
-No es muy estricto, así que no te has de preocupar de las mayúsculas, comas, etc.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="489"/>
+        <location filename="../src/optionsdialog.cpp" line="490"/>
         <source>Start!</source>
         <translation>¡Comenzar!</translation>
     </message>
@@ -636,7 +606,7 @@ No es muy estricto, así que no te has de preocupar de las mayúsculas, comas, e
         <translation>T.A.</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="119"/>
+        <location filename="../src/ranking.cpp" line="124"/>
         <source>What?? Zero points!!
 You&apos;re all sooo bad!</source>
         <comment>Plural, all players</comment>
@@ -644,7 +614,7 @@ You&apos;re all sooo bad!</source>
 ¡Sois todos muuuy malos!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="125"/>
+        <location filename="../src/ranking.cpp" line="130"/>
         <source>Zero points!
 %1, you&apos;re very bad!!</source>
         <comment>%1 is the name of a player</comment>
@@ -652,44 +622,44 @@ You&apos;re all sooo bad!</source>
 ¡¡%1, se te da muy mal!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="141"/>
+        <location filename="../src/ranking.cpp" line="146"/>
         <source>Draw between %1 and %2!</source>
         <comment>%1 and %2 are player names</comment>
         <translation>¡Empate entrer %1 y %2!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="151"/>
+        <location filename="../src/ranking.cpp" line="156"/>
         <source>You&apos;re very good!!</source>
         <translation>¡¡Se te da muy bien!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="158"/>
+        <location filename="../src/ranking.cpp" line="163"/>
         <source>Congratulations, %1!!</source>
         <comment>%1 is the name of the winner</comment>
         <translation>¡Felicidades, %1!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="168"/>
+        <location filename="../src/ranking.cpp" line="173"/>
         <source>That was amazing!!</source>
         <translation>¡¡Ha sido increíble!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="172"/>
+        <location filename="../src/ranking.cpp" line="177"/>
         <source>That was quite good!</source>
         <translation>¡Ha estado bastante bien!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="176"/>
+        <location filename="../src/ranking.cpp" line="181"/>
         <source>You can do better...</source>
         <translation>Puedes hacerlo mejor...</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="155"/>
+        <location filename="../src/ranking.cpp" line="160"/>
         <source>You&apos;re good!</source>
         <translation>¡Eres bueno!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="192"/>
+        <location filename="../src/ranking.cpp" line="197"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
