@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr">
+<TS version="2.1" language="fr">
 <context>
     <name>AnswerBox</name>
     <message>
@@ -110,18 +110,18 @@ Le scan peut durer longtemps, et le programme peut ne plus répondre tant que ce
     <message>
         <location filename="../src/auralwindow.cpp" line="668"/>
         <source>Maybe you don&apos;t have any Phonon backends installed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Peut-être que vous n&apos;avez aucun backend Phonon d&apos;installé.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="789"/>
+        <location filename="../src/auralwindow.cpp" line="790"/>
         <source>%1 songs available</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 chansons disponibles</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1122"/>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. Feel free to add your contact information, such as e-mail. If there was another translator before you, add your name after theirs ;)</comment>
-        <translation type="unfinished">Traduction française par ntome.</translation>
+        <translation>Traduction française par ntome, Adrien DAUGABEL et David GEIGER.</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="944"/>
@@ -142,7 +142,7 @@ Peut-être que votre backend Phonon ne supporte pas le format de fichier MP3.</t
     <message>
         <location filename="../src/auralwindow.cpp" line="1030"/>
         <source>Time&apos;s up!!</source>
-        <translation>Délai dépassé !</translation>
+        <translation>Temps écoulé !!</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1106"/>
@@ -154,10 +154,6 @@ Peut-être que votre backend Phonon ne supporte pas le format de fichier MP3.</t
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz charge toute votre musique depuis un certain dossier et pose des questions dessus, en jouant un petit morceau de chaque musique comme indice.</translation>
     </message>
-    <message>
-        <source>Main screen image based on Oxygen icons: http://www.oxygen-icons.org/ (LGPL licensed)</source>
-        <translation type="obsolete">Image de l&apos;écran principal basé sur les icones Oxygen :  http://www.oxygen-icons.org/ (licence LGPL)</translation>
-    </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="777"/>
         <source>Starting!</source>
@@ -166,17 +162,17 @@ Peut-être que votre backend Phonon ne supporte pas le format de fichier MP3.</t
     <message>
         <location filename="../src/auralwindow.cpp" line="264"/>
         <source>Good</source>
-        <translation type="unfinished">Bon</translation>
+        <translation>Bon</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="273"/>
         <source>Bad</source>
-        <translation type="unfinished">Mauvais</translation>
+        <translation>Mauvais</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="282"/>
         <source>Timed out</source>
-        <translation type="unfinished"></translation>
+        <translation>Temps écoulé</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="778"/>
@@ -186,7 +182,7 @@ Peut-être que votre backend Phonon ne supporte pas le format de fichier MP3.</t
     <message>
         <location filename="../src/auralwindow.cpp" line="779"/>
         <source>GO!!</source>
-        <translation>PARTEZ !</translation>
+        <translation>PARTEZ !!</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="780"/>
@@ -196,22 +192,22 @@ Peut-être que votre backend Phonon ne supporte pas le format de fichier MP3.</t
     <message>
         <location filename="../src/auralwindow.cpp" line="1031"/>
         <source>The answer was:</source>
-        <translation type="unfinished"></translation>
+        <translation>La réponse était :</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1129"/>
         <source>Thanks to all the testers, translators and packagers, who help make Auralquiz better!</source>
-        <translation type="unfinished"></translation>
+        <translation>Merci à tous les testeurs, traducteurs et packageurs, qui contribuent à l&apos;amélioration d&apos;Auralquiz !</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1133"/>
         <source>Auralquiz is licensed under the GNU GPL license.</source>
-        <translation type="unfinished"></translation>
+        <translation>Auralquiz est sous licence GNU GPL.</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1135"/>
         <source>Main screen image and some icons are based on Oxygen icons, under LGPL license.</source>
-        <translation type="unfinished"></translation>
+        <translation>L&apos;image de l&apos;écran principal et les icônes sont basés sur les icones Oxygen, sous licence LGPL.</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1198"/>
@@ -244,43 +240,43 @@ Vous avez besoin de musique d&apos;au moins 5 artistes différents pour pouvoir
         <location filename="../src/auralwindow.cpp" line="1373"/>
         <source>Go, %1!</source>
         <comment>%1=player&apos;s name</comment>
-        <translation type="unfinished">Allez, %1 !</translation>
+        <translation>Allez, %1 !</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1470"/>
         <source>%1 by %2</source>
         <comment>1=song title, 2=author name</comment>
-        <translation type="unfinished"></translation>
+        <translation>%1 par %2</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1501"/>
         <source>Correct answer was:</source>
-        <translation type="unfinished"></translation>
+        <translation>La bonne réponse était :</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1572"/>
         <source>End game?</source>
-        <translation type="unfinished"></translation>
+        <translation>Terminer la partie ?</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1573"/>
         <source>Are you sure you want to end this game?</source>
-        <translation type="unfinished"></translation>
+        <translation>Etes-vous sûr de vouloir terminer cette partie ?</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1575"/>
         <source>&amp;Yes, end it</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Oui, terminer</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1575"/>
         <source>&amp;No</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Non</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1379"/>
         <source>Next!</source>
-        <translation>Au suivant !</translation>
+        <translation>Suivant !</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1408"/>
@@ -290,7 +286,7 @@ Vous avez besoin de musique d&apos;au moins 5 artistes différents pour pouvoir
     <message>
         <location filename="../src/auralwindow.cpp" line="1454"/>
         <source>Correct!!</source>
-        <translation>Correct !</translation>
+        <translation>Correct !!</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1455"/>
@@ -300,7 +296,7 @@ Vous avez besoin de musique d&apos;au moins 5 artistes différents pour pouvoir
     <message>
         <location filename="../src/auralwindow.cpp" line="1456"/>
         <source>That&apos;s right!</source>
-        <translation>C&apos;est ça !</translation>
+        <translation>C&apos;est juste !</translation>
     </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="1457"/>
@@ -340,7 +336,7 @@ Vous avez besoin de musique d&apos;au moins 5 artistes différents pour pouvoir
     <message>
         <location filename="../src/auralwindow.cpp" line="1490"/>
         <source>FAIL!</source>
-        <translation>FAIL !</translation>
+        <translation>RATÉ !</translation>
     </message>
 </context>
 <context>
@@ -348,95 +344,89 @@ Vous avez besoin de musique d&apos;au moins 5 artistes différents pour pouvoir
     <message>
         <location filename="../src/musicanalyzer.cpp" line="125"/>
         <source>Configure your music folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurer votre dossier de musique</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="214"/>
         <source>Analyzing music. Please wait</source>
-        <translation type="unfinished">Analyse de la musique. Veuillez patienter</translation>
+        <translation>Analyse de la musique. Veuillez patienter</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="223"/>
         <source>Getting list of files under
 %1</source>
         <comment>%1 is a folder</comment>
-        <translation type="unfinished"></translation>
+        <translation>Obtention de la liste des fichiers dans %1</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="227"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Annuler</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="230"/>
         <source>Listing files...</source>
-        <translation type="unfinished"></translation>
+        <translation>Liste les fichiers...</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="359"/>
+        <location filename="../src/musicanalyzer.cpp" line="361"/>
         <source>Please reload music info</source>
-        <translation type="unfinished"></translation>
+        <translation>Merci de recharger les informations de la musique</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="256"/>
         <source>Music analysis was cancelled</source>
-        <translation type="unfinished"></translation>
+        <translation>L&apos;analyse de la musique a été annulée</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="269"/>
         <source>There are no valid music files in your selected music directory.</source>
-        <translation type="unfinished">Il n&apos;y a pas de fichier de musique valide dans le dossier de musique sélectionné.</translation>
+        <translation>Il n&apos;y a pas de fichier de musique valide dans le dossier de musique sélectionné.</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="272"/>
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="unfinished">Veuillez sélectionner un autre dossier contenant des fichiers Ogg, FLAC ou MP3 puis réessayez.</translation>
+        <translation>Veuillez sélectionner un autre dossier contenant des fichiers Ogg, FLAC ou MP3 puis réessayez.</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="276"/>
         <source>There is no music!</source>
-        <translation type="unfinished">Il n&apos;y a pas de musique !</translation>
-    </message>
-    <message>
-        <source>There are no valid music files in your selected music directory.
-Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="obsolete">Il n&apos;y a pas de fichier de musique valide dans le dossier de musique sélectionné.
-Veuillez sélectionner un autre dossier contenant des fichiers Ogg, FLAC ou MP3 puis réessayez.</translation>
+        <translation>Il n&apos;y a pas de musique !</translation>
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="383"/>
+        <location filename="../src/musicanalyzer.cpp" line="385"/>
         <source>Please choose another music folder</source>
-        <translation type="unfinished">Veuillez sélectionner un autre dossier de musique</translation>
+        <translation>Veuillez sélectionner un autre dossier de musique</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
-        <translation type="unfinished">Analyse %1 fichiers
+        <translation>Analyse %1 fichiers
 dans %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="295"/>
+        <location filename="../src/musicanalyzer.cpp" line="297"/>
         <source>Cancel analysis</source>
-        <translation type="unfinished">Annuler l&apos;analyse</translation>
+        <translation>Annuler l&apos;analyse</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="298"/>
+        <location filename="../src/musicanalyzer.cpp" line="300"/>
         <source>Analyzing your music...</source>
-        <translation type="unfinished">Analyse votre musique...</translation>
+        <translation>Analyse votre musique...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="384"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
-        <translation type="unfinished"></translation>
+        <translation>Le dossier que vous avez sélectionné n&apos;a pas assez de fichiers de musique valide</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="394"/>
+        <location filename="../src/musicanalyzer.cpp" line="396"/>
         <source>&amp;Start game</source>
-        <translation type="unfinished">&amp;Démarrer le jeu</translation>
+        <translation>&amp;Démarrer le jeu</translation>
     </message>
 </context>
 <context>
@@ -459,12 +449,12 @@ dans %2</translation>
     <message>
         <location filename="../src/optionsdialog.cpp" line="83"/>
         <source>&amp;Easier</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Plus facile</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="98"/>
         <source>&amp;Harder</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Plus difficile</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="126"/>
@@ -499,7 +489,7 @@ dans %2</translation>
     <message>
         <location filename="../src/optionsdialog.cpp" line="225"/>
         <source>Save and &amp;reload music</source>
-        <translation>Sauver et &amp;recharger la musique</translation>
+        <translation>Enregistrer et &amp;recharger la musique</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="234"/>
@@ -538,51 +528,35 @@ dans %2</translation>
     <message>
         <location filename="../src/optionsdialog.cpp" line="355"/>
         <source>HARD!!</source>
-        <translation>Difficile !</translation>
+        <translation>Difficile !!</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="356"/>
         <source>Hardcore! Type the answer</source>
-        <translation>Super difficile ! Tapez la réponse</translation>
+        <translation>Super difficile ! Taper la réponse</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="363"/>
         <source>In this level you&apos;ll have to type the answer.</source>
-        <translation type="unfinished">Dans ce niveau, vous devrez taper la réponse.</translation>
+        <translation>Dans ce niveau, vous devrez taper la réponse.</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="366"/>
         <source>It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="unfinished">Ce n&apos;est pas strict, vous n&apos;avez pas besoin de mettre les majuscules, virgules etc.</translation>
+        <translation>Ce n&apos;est pas trop strict, vous n&apos;avez pas besoin de mettre les majuscules, virgules etc.</translation>
     </message>
     <message>
         <location filename="../src/optionsdialog.cpp" line="373"/>
         <source>In this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="unfinished">Dans ce niveau, vous devez cliquer sur le bon bouton, ou appuyer sur les touches 1, 2, 3 ou 4 de votre clavier.</translation>
+        <translation>Dans ce niveau, vous devrez cliquer sur le bon bouton, ou appuyer sur les touches 1, 2, 3 ou 4 de votre clavier.</translation>
     </message>
     <message>
-        <source>Is this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">Dans ce niveau, vous devez cliquer sur le bon bouton, ou appuyer sur les touches 1, 2, 3 ou 4 de votre clavier.</translation>
-    </message>
-    <message>
-        <source>In this level you&apos;ll have to type the answer.
-It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="obsolete">Dans ce niveau, vous devrez taper la réponse.
-Ce n&apos;est pas strict, vous n&apos;avez pas besoin de mettre les majuscules, virgules etc.</translation>
-    </message>
-    <message>
-        <source>Is this level you&apos;ll have to click the correct button,
-or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">Dans ce niveau, vous devez cliquer sur le bon bouton,
-ou appuyer sur les touches 1, 2, 3 ou 4 de votre clavier.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="459"/>
+        <location filename="../src/optionsdialog.cpp" line="460"/>
         <source>&amp;Save options</source>
-        <translation>&amp;Sauver les options</translation>
+        <translation>&amp;Enregistrer les options</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="489"/>
+        <location filename="../src/optionsdialog.cpp" line="490"/>
         <source>Start!</source>
         <translation>Démarrer !</translation>
     </message>
@@ -592,12 +566,12 @@ ou appuyer sur les touches 1, 2, 3 ou 4 de votre clavier.</translation>
     <message>
         <location filename="../src/ranking.cpp" line="27"/>
         <source>Game ended</source>
-        <translation>Jeu terminé</translation>
+        <translation>Partie terminée</translation>
     </message>
     <message>
         <location filename="../src/ranking.cpp" line="33"/>
         <source>All questions done!</source>
-        <translation>Fin des questions !</translation>
+        <translation>Toutes les questions sont faites!</translation>
     </message>
     <message>
         <location filename="../src/ranking.cpp" line="35"/>
@@ -636,60 +610,60 @@ ou appuyer sur les touches 1, 2, 3 ou 4 de votre clavier.</translation>
         <translation>D.D.</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="119"/>
+        <location filename="../src/ranking.cpp" line="124"/>
         <source>What?? Zero points!!
 You&apos;re all sooo bad!</source>
         <comment>Plural, all players</comment>
-        <translation>Comment ? Aucun point !
-Mais vous êtes tous mauvais !</translation>
+        <translation>Quoi ? Aucun point !!
+Mais vous êtes tous si mauvais !</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="125"/>
+        <location filename="../src/ranking.cpp" line="130"/>
         <source>Zero points!
 %1, you&apos;re very bad!!</source>
         <comment>%1 is the name of a player</comment>
         <translation>Aucun point !
-%1, vous êtes très mauvais !</translation>
+%1, vous êtes très mauvais !!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="141"/>
+        <location filename="../src/ranking.cpp" line="146"/>
         <source>Draw between %1 and %2!</source>
         <comment>%1 and %2 are player names</comment>
         <translation>Égalité entre %1 et %2 !</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="151"/>
+        <location filename="../src/ranking.cpp" line="156"/>
         <source>You&apos;re very good!!</source>
         <translation>Vous êtes très bon !</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="155"/>
+        <location filename="../src/ranking.cpp" line="160"/>
         <source>You&apos;re good!</source>
         <translation>Vous êtes bon !</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="158"/>
+        <location filename="../src/ranking.cpp" line="163"/>
         <source>Congratulations, %1!!</source>
         <comment>%1 is the name of the winner</comment>
-        <translation>Félicitations, %1 !</translation>
+        <translation>Félicitations, %1 !!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="168"/>
+        <location filename="../src/ranking.cpp" line="173"/>
         <source>That was amazing!!</source>
-        <translation type="unfinished"></translation>
+        <translation>C&apos;était formidable !!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="172"/>
+        <location filename="../src/ranking.cpp" line="177"/>
         <source>That was quite good!</source>
-        <translation>C&apos;était bien !</translation>
+        <translation>C&apos;était plutôt bien !</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="176"/>
+        <location filename="../src/ranking.cpp" line="181"/>
         <source>You can do better...</source>
-        <translation>Peut mieux faire...</translation>
+        <translation>Tu peux mieux faire...</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="192"/>
+        <location filename="../src/ranking.cpp" line="197"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
