@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="gl">
+<TS version="2.1" language="gl">
 <context>
     <name>AnswerBox</name>
     <message>
@@ -77,7 +77,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="789"/>
+        <location filename="../src/auralwindow.cpp" line="790"/>
         <source>%1 songs available</source>
         <translation type="unfinished"></translation>
     </message>
@@ -139,10 +139,6 @@ A mensaxe de erro foi: %1
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz carga toda a música dun cartafol indicado e fai preguntas sobre ela, reproducindo un cacho pequeno de cada ficheiro de música como pista.</translation>
     </message>
-    <message>
-        <source>Main screen image based on Oxygen icons: http://www.oxygen-icons.org/ (LGPL licensed)</source>
-        <translation type="obsolete">Imaxe da pantalla principal baseada nas iconas Oxygen: http://www.oxygen-icons.org/ (licenza LGPL)</translation>
-    </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="777"/>
         <source>Starting!</source>
@@ -375,7 +371,7 @@ Necesitas música de polo menos 5 artistas diferentes para poder xerar preguntas
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="359"/>
+        <location filename="../src/musicanalyzer.cpp" line="361"/>
         <source>Please reload music info</source>
         <translation>Volve a cargar a información da música</translation>
     </message>
@@ -399,42 +395,36 @@ Necesitas música de polo menos 5 artistas diferentes para poder xerar preguntas
         <source>There is no music!</source>
         <translation>Non hai música!</translation>
     </message>
-    <message>
-        <source>There are no valid music files in your selected music directory.
-Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="obsolete">Non hai ficheiros de música que poder empregar no cartafol de música seleccionado.
-Escolle outro cartafol que conteña ficheiros Ogg, FLAC ou MP3, e téntao de novo.</translation>
-    </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="383"/>
+        <location filename="../src/musicanalyzer.cpp" line="385"/>
         <source>Please choose another music folder</source>
         <translation>Escolle outro cartafol de música</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
         <translation>Analizando %1 ficheiros en %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="295"/>
+        <location filename="../src/musicanalyzer.cpp" line="297"/>
         <source>Cancel analysis</source>
         <translation>Cancelar a análise</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="298"/>
+        <location filename="../src/musicanalyzer.cpp" line="300"/>
         <source>Analyzing your music...</source>
         <translation>Analizando a túa música...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="384"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="394"/>
+        <location filename="../src/musicanalyzer.cpp" line="396"/>
         <source>&amp;Start game</source>
         <translation>&amp;Comezar o xogo</translation>
     </message>
@@ -519,17 +509,7 @@ under %2</source>
         <translation type="unfinished">Neste nivel terás que premer no botón correcto, ou premer nas nas teclas 1, 2, 3 e 4 do teclado.</translation>
     </message>
     <message>
-        <source>Is this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">Neste nivel terás que premer no botón correcto, ou premer nas nas teclas 1, 2, 3 e 4 do teclado.</translation>
-    </message>
-    <message>
-        <source>Is this level you&apos;ll have to click the correct button,
-or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">Neste nivel terás que premer no botón correcto,
-ou premer nas nas teclas 1, 2, 3 e 4 do teclado.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="459"/>
+        <location filename="../src/optionsdialog.cpp" line="460"/>
         <source>&amp;Save options</source>
         <translation>&amp;Gardar as opcións</translation>
     </message>
@@ -574,13 +554,7 @@ ou premer nas nas teclas 1, 2, 3 e 4 do teclado.</translation>
         <translation>Moi difícil! Escribe a resposta</translation>
     </message>
     <message>
-        <source>In this level you&apos;ll have to type the answer.
-It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="obsolete">Neste nivel terás que escribir a resposta.
-Non é moi estrito, así que non terás que preocuparte das maiúsculas, comas, etc.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="489"/>
+        <location filename="../src/optionsdialog.cpp" line="490"/>
         <source>Start!</source>
         <translation>Comezar!</translation>
     </message>
@@ -634,7 +608,7 @@ Non é moi estrito, así que non terás que preocuparte das maiúsculas, comas,
         <translation>T.E.</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="119"/>
+        <location filename="../src/ranking.cpp" line="124"/>
         <source>What?? Zero points!!
 You&apos;re all sooo bad!</source>
         <comment>Plural, all players</comment>
@@ -642,7 +616,7 @@ You&apos;re all sooo bad!</source>
 Sodes todos moooi malos!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="125"/>
+        <location filename="../src/ranking.cpp" line="130"/>
         <source>Zero points!
 %1, you&apos;re very bad!!</source>
         <comment>%1 is the name of a player</comment>
@@ -650,44 +624,44 @@ Sodes todos moooi malos!</translation>
 %1, es moi malo!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="141"/>
+        <location filename="../src/ranking.cpp" line="146"/>
         <source>Draw between %1 and %2!</source>
         <comment>%1 and %2 are player names</comment>
         <translation>Empate entre %1 y %2!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="151"/>
+        <location filename="../src/ranking.cpp" line="156"/>
         <source>You&apos;re very good!!</source>
         <translation>Es moi bo!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="158"/>
+        <location filename="../src/ranking.cpp" line="163"/>
         <source>Congratulations, %1!!</source>
         <comment>%1 is the name of the winner</comment>
         <translation>Parabéns, %1!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="168"/>
+        <location filename="../src/ranking.cpp" line="173"/>
         <source>That was amazing!!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="172"/>
+        <location filename="../src/ranking.cpp" line="177"/>
         <source>That was quite good!</source>
         <translation>Estiveches bastante ben!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="176"/>
+        <location filename="../src/ranking.cpp" line="181"/>
         <source>You can do better...</source>
         <translation>Podes facelo mellor...</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="155"/>
+        <location filename="../src/ranking.cpp" line="160"/>
         <source>You&apos;re good!</source>
         <translation>Es bo!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="192"/>
+        <location filename="../src/ranking.cpp" line="197"/>
         <source>&amp;OK</source>
         <translation>&amp;Aceptar</translation>
     </message>
