@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="it">
+<TS version="2.1" language="it">
 <context>
     <name>AnswerBox</name>
     <message>
@@ -77,7 +77,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="789"/>
+        <location filename="../src/auralwindow.cpp" line="790"/>
         <source>%1 songs available</source>
         <translation type="unfinished"></translation>
     </message>
@@ -139,10 +139,6 @@ Forse il tuo Phonon-backend non supporta i file in formato MP3.</translation>
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz carica tutta la tua musica da una cartella specificata e ti fa domande su di essa, riproducendo un breve pezzo di ogni file come indizio.</translation>
     </message>
-    <message>
-        <source>Main screen image based on Oxygen icons: http://www.oxygen-icons.org/ (LGPL licensed)</source>
-        <translation type="obsolete">Immagine della schermata principale basata sulle icone Oxygen: http://www.oxygen-icons.org/ (LGPL licensed)</translation>
-    </message>
     <message>
         <location filename="../src/auralwindow.cpp" line="777"/>
         <source>Starting!</source>
@@ -374,7 +370,7 @@ Devi avere canzoni di almeno 5 artisti diversi per poter generare le domande.</t
     </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="359"/>
+        <location filename="../src/musicanalyzer.cpp" line="361"/>
         <source>Please reload music info</source>
         <translation type="unfinished"></translation>
     </message>
@@ -398,42 +394,36 @@ Devi avere canzoni di almeno 5 artisti diversi per poter generare le domande.</t
         <source>There is no music!</source>
         <translation type="unfinished">Musica non trovata!</translation>
     </message>
-    <message>
-        <source>There are no valid music files in your selected music directory.
-Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="obsolete">Non ci sono file musicali validi nella cartella selezionata.
-Seleziona un&apos;altra cartella contenente file Ogg, FLAC o MP3, e prova di nuovo.</translation>
-    </message>
     <message>
         <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="383"/>
+        <location filename="../src/musicanalyzer.cpp" line="385"/>
         <source>Please choose another music folder</source>
         <translation type="unfinished">Scegli un&apos;altra cartella della musica</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
         <translation type="unfinished">Analisi %1 file in %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="295"/>
+        <location filename="../src/musicanalyzer.cpp" line="297"/>
         <source>Cancel analysis</source>
         <translation type="unfinished">Annulla analisi</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="298"/>
+        <location filename="../src/musicanalyzer.cpp" line="300"/>
         <source>Analyzing your music...</source>
         <translation type="unfinished">Analisi della tua musica...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="384"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="394"/>
+        <location filename="../src/musicanalyzer.cpp" line="396"/>
         <source>&amp;Start game</source>
         <translation type="unfinished">Inizio &amp;gioco</translation>
     </message>
@@ -516,17 +506,7 @@ under %2</source>
         <translation type="unfinished">In questo livello devi cliccare il pulsante corretto, o premere i tasti 1, 2, 3 e 4 sulla tastiera.</translation>
     </message>
     <message>
-        <source>Is this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">In questo livello devi cliccare il pulsante corretto, o premere i tasti 1, 2, 3 e 4 sulla tastiera.</translation>
-    </message>
-    <message>
-        <source>Is this level you&apos;ll have to click the correct button,
-or press the 1, 2, 3 and 4 keys in your keyboard.</source>
-        <translation type="obsolete">In questo livello devi cliccare il pulsante corretto,
-o premere i tasti 1, 2, 3 e 4 sulla tastiera.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="459"/>
+        <location filename="../src/optionsdialog.cpp" line="460"/>
         <source>&amp;Save options</source>
         <translation>&amp;Salva opzioni</translation>
     </message>
@@ -571,13 +551,7 @@ o premere i tasti 1, 2, 3 e 4 sulla tastiera.</translation>
         <translation>Estremo! Scrivi la risposta</translation>
     </message>
     <message>
-        <source>In this level you&apos;ll have to type the answer.
-It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
-        <translation type="obsolete">In questo livello devi digitare la risposta.
-Non è molto stringente, quindi non ti devi preoccupare di maiuscole, virgole e simili.</translation>
-    </message>
-    <message>
-        <location filename="../src/optionsdialog.cpp" line="489"/>
+        <location filename="../src/optionsdialog.cpp" line="490"/>
         <source>Start!</source>
         <translation>Inizio!</translation>
     </message>
@@ -631,7 +605,7 @@ Non è molto stringente, quindi non ti devi preoccupare di maiuscole, virgole e
         <translation>T.S.</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="119"/>
+        <location filename="../src/ranking.cpp" line="124"/>
         <source>What?? Zero points!!
 You&apos;re all sooo bad!</source>
         <comment>Plural, all players</comment>
@@ -639,7 +613,7 @@ You&apos;re all sooo bad!</source>
 Siete proprio scarsi!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="125"/>
+        <location filename="../src/ranking.cpp" line="130"/>
         <source>Zero points!
 %1, you&apos;re very bad!!</source>
         <comment>%1 is the name of a player</comment>
@@ -647,44 +621,44 @@ Siete proprio scarsi!</translation>
 %1, sei proprio scarso!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="141"/>
+        <location filename="../src/ranking.cpp" line="146"/>
         <source>Draw between %1 and %2!</source>
         <comment>%1 and %2 are player names</comment>
         <translation>Pareggio tra %1 e %2!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="151"/>
+        <location filename="../src/ranking.cpp" line="156"/>
         <source>You&apos;re very good!!</source>
         <translation>Sei molto bravo!!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="158"/>
+        <location filename="../src/ranking.cpp" line="163"/>
         <source>Congratulations, %1!!</source>
         <comment>%1 is the name of the winner</comment>
         <translation>Congratulazioni, %1!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="168"/>
+        <location filename="../src/ranking.cpp" line="173"/>
         <source>That was amazing!!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="172"/>
+        <location filename="../src/ranking.cpp" line="177"/>
         <source>That was quite good!</source>
         <translation>È andata abbastanza bene!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="176"/>
+        <location filename="../src/ranking.cpp" line="181"/>
         <source>You can do better...</source>
         <translation>Puoi fare di meglio...</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="155"/>
+        <location filename="../src/ranking.cpp" line="160"/>
         <source>You&apos;re good!</source>
         <translation>Sei bravo!</translation>
     </message>
     <message>
-        <location filename="../src/ranking.cpp" line="192"/>
+        <location filename="../src/ranking.cpp" line="197"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
